Range-v3: range/v3/view/set_algorithm.hpp File Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Classes | Typedefs | Functions
set_algorithm.hpp File Reference

## Classes
struct | ranges::v3::detail::set_intersection_cursor< IsConst, Rng1, Rng2, C, P1, P2 >
struct | ranges::v3::detail::set_symmetric_difference_cursor< IsConst, Rng1, Rng2, C, P1, P2 >
struct | ranges::v3::detail::set_union_cursor< IsConst, Rng1, Rng2, C, P1, P2 >
struct | ranges::v3::view::set_difference_fn
struct | ranges::v3::view::set_intersection_fn
struct | ranges::v3::view::set_symmetric_difference_fn
struct | ranges::v3::view::set_union_fn

## Typedefs
template<typename Rng1 , typename Rng2 , typename C , typename P1 , typename P2 >
using | ranges::v3::set_difference_view = detail::set_algorithm_view< Rng1, Rng2, C, P1, P2, detail::set_difference_cursor, detail::set_difference_cardinality(range_cardinality< Rng1 >::value, range_cardinality< Rng2 >::value)>
template<typename Rng1 , typename Rng2 , typename C , typename P1 , typename P2 >
using | ranges::v3::set_intersection_view = detail::set_algorithm_view< Rng1, Rng2, C, P1, P2, detail::set_intersection_cursor, detail::set_intersection_cardinality(range_cardinality< Rng1 >::value, range_cardinality< Rng2 >::value)>
template<typename Rng1 , typename Rng2 , typename C , typename P1 , typename P2 >
using | ranges::v3::set_symmetric_difference_view = detail::set_algorithm_view< Rng1, Rng2, C, P1, P2, detail::set_symmetric_difference_cursor, detail::set_symmetric_difference_cardinality(range_cardinality< Rng1 >::value, range_cardinality< Rng2 >::value)>
template<typename Rng1 , typename Rng2 , typename C , typename P1 , typename P2 >
using | ranges::v3::set_union_view = detail::set_algorithm_view< Rng1, Rng2, C, P1, P2, detail::set_union_cursor, detail::set_union_cardinality(range_cardinality< Rng1 >::value, range_cardinality< Rng2 >::value)>

## Functions
constexpr cardinality | ranges::v3::detail::set_intersection_cardinality (cardinality c1, cardinality c2)
constexpr cardinality | ranges::v3::detail::set_symmetric_difference_cardinality (cardinality c1, cardinality c2)
constexpr cardinality | ranges::v3::detail::set_union_cardinality (cardinality c1, cardinality c2)